/**
 * Följsamma tabeller.
 *
 * Skriptet preparerar alla tabeller på sidan så att de kan presenteras i
 * linjär form i smala vyer.
 *
 * Fungerar bara på enkla tabeller med en rubrikcell per kolumn och
 * inga `td` med colspan.
 */
((doc) => {
    "use strict";


    /**
     * Preparera en tabell för linjär presentation.
     *
     * Sätt ett `data-header`-attribut på varje `td` i tabellen.
     * Sätt därefter en klass på tabellen som visar att den tål linjär
     * presentation.
     *
     * @param {HTMLTableElement} table Tabellen som ska anpassas.
     */
    function linearize(table) {
        const headers = Array.prototype.slice
            .call(table.querySelectorAll("thead th"))
            .map((th) => th.innerText);

        for (let b = 0, nb = table.tBodies.length; b < nb; ++b) {
            const tbody = table.tBodies.item(b);

            for (let r = 0, nr = tbody.rows.length; r < nr; ++r) {
                const row = tbody.rows.item(r);

                if (row.cells.length === headers.length) {
                    headers.forEach((header, index) => {
                        row.cells.item(index).dataset["header"] = header;
                    });
                }
            }
        }

        table.classList.add("linearizable");
    }


    /*
     * Initiering.
     */

    // Kontrollera kompatibilitet
    if (   "undefined" === typeof Array.prototype.slice
        || "undefined" === typeof doc.querySelectorAll
        || "undefined" === typeof doc.body.classList
    ) {
        return;
    }

    // Iterera över alla tabeller och förbered dem för linjär presentation.
    doc.querySelectorAll("table").forEach((table) => linearize(table));
})(document);
